@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Measure the emotional sentiment of text
 
-our $VERSION = '0.0503';
+our $VERSION = '0.0504';
 
 use Moo;
 use strictures 2;
@@ -117,19 +117,6 @@ sub nrc_sentiment {
 
         my @words = split /\s+/, $sentence;
 
-        my $initial = {
-            anger        => 0,
-            anticipation => 0,
-            disgust      => 0,
-            fear         => 0,
-            joy          => 0,
-            negative     => 0,
-            positive     => 0,
-            sadness      => 0,
-            surprise     => 0,
-            trust        => 0,
-        };
-
         my $score;
 
         for my $word ( @words ) {
@@ -140,7 +127,7 @@ sub nrc_sentiment {
             }
         }
 
-        $score = $initial
+        $score = $null_state
             unless $score;
 
         push @scores, $score;
@@ -163,7 +150,7 @@ Lingua::EN::Opinion - Measure the emotional sentiment of text
 
 =head1 VERSION
 
-version 0.0503
+version 0.0504
 
 =head1 SYNOPSIS
 
@@ -254,7 +241,7 @@ This is given by a 0/1 list of these 10 emotional elements:
   surprise
   trust
 
-This method sets the B<nrc_scores> attribute.
+This method sets the B<nrc_scores> and B<sentences> attributes.
 
 =head1 SEE ALSO
 
